%%
%% This is file `pfuef.cls', pdflatex class file to generate slides
%% without any post processing.
%% Copyright (C) 2004  Reinhard Furrer
%%                     furrer@ucar.edu
%% 
%% This program is free software; you can redistribute it and/or
%% modify it under the terms of the GNU General Public License
%% as published by the Free Software Foundation; either version 2
%% of the License, or (at your option) any later version.
%% 
%% This program is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%% GNU General Public License for more details.
%% 
%% You should have received a copy of the GNU General Public License
%% along with this program; if not, write to the Free Software
%% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
%% USA.
%% 
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{pfuef}
              [2004/02/12 v0.1 slides]

\RequirePackage[usenames,dvipsnames]{color}
\RequirePackage{graphicx}
\RequirePackage{calc}
\RequirePackage{ifthen}
\usepackage{amssymb,amsmath}
\usepackage[colorlinks=true]{hyperref}


\newif\iflightbg\lightbgfalse
\newif\ifppremarks\ppremarksfalse
\newif\ifmkfooter\mkfootertrue
\newif\ifbackground\backgroundfalse


\InputIfFileExists{rgb.tex}{
  \typeout{Loading color table}}{
  \typeout{Color table ain't available.}

  \definecolor{gray30}{rgb}{0.3,0.3,0.3}
  \definecolor{gray50}{rgb}{0.5,0.5,0.5}
  \definecolor{gray60}{rgb}{0.6,0.6,0.6}
  \definecolor{DarkBlue}{rgb}{0,0,0.5451}
  \definecolor{LightSkyBlue}{rgb}{0.52941,0.80784,0.98039}
  \definecolor{khaki}{rgb}{0.94118,0.90196,0.54902}

}
\DeclareOption{background}{
  \backgroundtrue
}


\DeclareOption{ppremarks}{
  \ppremarkstrue
}

\DeclareOption{lightbg}{
  \definecolor{bgblue}{rgb}{0.1882353,0.3607843,0.7529412}
  \pagecolor{white}

  \def\tcb{\color{bgblue}}
  \def\tcg{\color{gray30}}
  \def\tct{\color{black}}
  \def\tcd{\color{gray50}}

  \def\coldot{\@figuredir blueonwhitedot.png}
  \lightbgtrue
}

\DeclareOption{final}{
  \definecolor{bgblue}{rgb}{0.1882353,0.3607843,0.7529412}
  \pagecolor{bgblue}

  \def\tcb{\color{bgblue}}
  \def\tcg{\color{gray60}}
  \def\tct{\color{white}}
  \def\tcd{\color{DarkBlue}}

  \def\coldot{\@figuredir grayontransdot.pdf}
}

\DeclareOption{landscape}{
  \paperheight210 mm
  \paperwidth 297 mm
  \textheight210 mm
  \textwidth 297 mm
  \headheight 0pt
  \headsep 0mm
  \oddsidemargin 0 mm
  \topmargin 0 mm
  \baselineskip 14pt
  \parskip 0mm
  \headsep 0 mm
  \hoffset -1in
  \voffset -1in
  \parindent 0mm
  \newdimen\sleftmargin
  \newdimen\srightmargin
  \newdimen\sbottommargin
  \newdimen\slidewidth

  \srightmargin 2cm
  \sleftmargin 3cm
  \sbottommargin 5cm
  \setlength{\slidewidth}{\paperwidth-\srightmargin-\sleftmargin}  
  \setlength{\evensidemargin}{\oddsidemargin}
}

\newcounter{slideno}
\setcounter{slideno}{0}

\ExecuteOptions{landscape,final}
\ProcessOptions

% input from slides.cls
\def\rmdefault{lcmss}        % no roman
\def\sfdefault{lcmss}
\def\ttdefault{lcmtt}
\def\itdefault{sl}
\def\sldefault{sl}
\def\bfdefault{bx}
\def\ifourteenpt{13.82}
\def\iseventeenpt{16.59}
\def\itwentypt{19.907}
\def\itwentyfourpt{23.89}
\def\itwentyninept{28.66}
\def\ithirtyfourpt{34.4}
\def\ifortyonept{41.28}
\def\@setfontsize@parms#1#2#3#4#5#6#7#8{%
   \lineskip #1\relax%
   \parskip #2\relax
   \abovedisplayskip #3\relax
   \belowdisplayskip #4\relax
   \abovedisplayshortskip #5\relax
   \belowdisplayshortskip #6\relax
  \setbox\strutbox=\hbox{\vrule \@height#7\p@\@depth#8\p@\@width\z@}%
  \baselineskip\baselinestretch\baselineskip
  \normalbaselineskip\baselineskip}
\DeclareMathSizes{13.82}{13.82}{10}{7}
\DeclareMathSizes{16.59}{16.59}{12}{7}
\DeclareMathSizes{19.907}{19.907}{16.59}{13.82}
\DeclareMathSizes{23.89}{23.89}{19.907}{16.59}
\DeclareMathSizes{28.66}{28.66}{23.89}{19.907}
\DeclareMathSizes{34.4}{34.4}{28.66}{23.89}
\DeclareMathSizes{41.28}{41.28}{34.4}{28.66}
\def\normalsize{%
      \@setfontsize\normalsize\itwentypt{28\p@ plus3\p@ minus4\p@}%
      \@setfontsize@parms
            {2pt}%
            {30\p@ plus18\p@ minus9\p@}%
            {15\p@ plus3\p@ minus3\p@}%
            {10\p@ plus3\p@ minus3\p@}%
            {10\p@ plus3\p@}
            \abovedisplayshortskip
            {17}{7}}
\normalsize
\def\small{\@setfontsize\small\iseventeenpt{19\p@ plus3\p@ minus\p@}%
           \@setfontsize@parms
            {2\p@}%
            {15\p@ plus15\p@ minus7\p@}%
            {12\p@ plus3\p@ minus3\p@}%
            {9\p@ plus3\p@ minus3\p@}%
            {6\p@ plus3\p@}%
            \abovedisplayshortskip
            {13.5}{5.6}}
\let\footnotesize=\small
\let\scriptsize=\small
\def\tiny{\@setfontsize\tiny\ifourteenpt{16\p@ plus2\p@ minus\p@}%
          \@setfontsize@parms
            {2pt}%
            {14\p@ plus3\p@ minus10\p@}%
            {11\p@ plus3\p@ minus10\p@}%
            \abovedisplayskip
            {8\p@ plus3\p@ minus5\p@}%
            {\z@ plus3\p@}%
            {10}{4}}
\def\large{\@setfontsize\large\itwentyfourpt{42\p@ plus8\p@ minus5\p@}%
           \@setfontsize@parms
            {2\p@}%
            {40\p@ plus20\p@ minus4\p@}%
            {20\p@ plus8\p@ minus3\p@}%
            \abovedisplayskip
            {10\p@ plus5\p@}%
            \abovedisplayshortskip
            {20}{8.5}}

\def\Large{\@setfontsize\Large\itwentyninept{48\p@ plus10\p@ minus6\p@}%
           \@setfontsize@parms
            {2\p@}%
            {48\p@ plus30\p@ minus6\p@}%
            {24\p@ plus10\p@ minus6\p@}%
            \abovedisplayskip
            {12\p@ plus8\p@}%
            \abovedisplayshortskip
            {27}{11}}

\def\LARGE{\@setfontsize\LARGE\ithirtyfourpt{52\p@ plus10\p@ minus6\p@}%
           \@setfontsize@parms
            {2\p@}%
            {52\p@ plus30\p@ minus6\p@}%
            {24\p@ plus10\p@ minus6\p@}%
            \abovedisplayskip
            {12\p@ plus8\p@}%
            \abovedisplayshortskip
            {27}{11}}

\def\huge{\@setfontsize\huge\ifortyonept{60\p@ plus10\p@ minus6\p@}%
           \@setfontsize@parms
            {2\p@}%
            {60\p@ plus30\p@ minus6\p@}%
            {24\p@ plus10\p@ minus6\p@}%
            \abovedisplayskip
            {12\p@ plus8\p@}%
            \abovedisplayshortskip
            {27}{11}}

\let\Huge\huge
\renewcommand\baselinestretch{}

\@lowpenalty   51
\@medpenalty  151
\@highpenalty 301




\@settopoint\topmargin
\DeclareMathVersion{invisible}
\SetSymbolFont{operators}{normal}
                 {OT1}{lcmss}{m}{n}
\SetSymbolFont{letters}{normal}
                 {OML}{lcmm}{m}{it}
\SetSymbolFont{symbols}{normal}
                 {OMS}{lcmsy}{m}{n}
\SetSymbolFont{largesymbols}{normal}
                 {OMX}{lcmex}{m}{n}
\SetSymbolFont{operators}{invisible}
                 {OT1}{lcmss}{m}{In}
\SetSymbolFont{letters}{invisible}
                 {OML}{lcmm}{m}{Iit}
\SetSymbolFont{symbols}{invisible}
                 {OMS}{lcmsy}{m}{In}
\SetSymbolFont{largesymbols}{invisible}
                  {OMX}{lcmex}{m}{In}

\def\@mainsize{\visible\tiny}

\setlength\leftmargini   {38\p@}
\setlength\leftmarginii  {30\p@}
\setlength\leftmarginiii {20\p@}
\setlength\leftmarginiv  {15\p@}
\setlength\leftmarginv   {15\p@}
\setlength\leftmarginvi  {10\p@}
\def\@listi{\leftmargin\leftmargini
            \parsep .5\parskip
            \topsep \parsep
            \itemsep\parskip
            \partopsep \z@}

\def\@listii{\leftmargin\leftmarginii
             \labelwidth\leftmarginii
             \advance\labelwidth-\labelsep
             \parsep .5\parskip
             \topsep \parsep
             \itemsep\parskip}
\def\@listiii{\leftmargin\leftmarginiii
              \labelwidth\leftmarginiii
              \advance\labelwidth-\labelsep}
\def\@listiv{\leftmargin\leftmarginiv
             \labelwidth\leftmarginiv
             \advance\labelwidth-\labelsep}
\def\@listv{\leftmargin\leftmarginv
            \labelwidth\leftmarginv
            \advance\labelwidth-\labelsep}
\def\@listvi{\leftmargin\leftmarginvi
             \labelwidth\leftmarginvi
             \advance\labelwidth-\labelsep}
\leftmargin\leftmargini
\labelwidth\leftmargini\advance\labelwidth-\labelsep

\newenvironment{description}{\list{}{\labelwidth\z@
                                     \itemindent-\leftmargin
                                     \let\makelabel\descriptionlabel}}
                            {\endlist}
\newcommand*{\descriptionlabel}[1]{\hspace\labelsep
                                \normalfont\bfseries #1}

\renewcommand\theenumi{\@arabic\c@enumi}
\renewcommand\theenumii{\@alph\c@enumii}
\renewcommand\theenumiii{\@roman\c@enumiii}
\renewcommand\theenumiv{\@Alph\c@enumiv}
\newcommand\labelenumi{\theenumi.}
\newcommand\labelenumii{(\theenumii)}
\newcommand\labelenumiii{\theenumiii.}
\newcommand\labelenumiv{\theenumiv.}
\renewcommand\p@enumii{\theenumi}
\renewcommand\p@enumiii{\theenumi(\theenumii)}
\renewcommand\p@enumiv{\p@enumiii\theenumiii}
\newcommand\labelitemi{{\tcg$\m@th\bullet$}}
\newcommand\labelitemii{\normalfont\bfseries \textendash}
\newcommand\labelitemiii{$\m@th\ast$}
\newcommand\labelitemiv{$\m@th\cdot$}
\setlength\arraycolsep{8\p@}
\setlength\tabcolsep{10\p@}
\setlength\arrayrulewidth{.6\p@}
\setlength\doublerulesep{3\p@}
\labelsep 10pt
\setlength\tabbingsep{\labelsep}
\skip\@mpfootins = \skip\footins
\setlength\fboxsep{5\p@}
\setlength\fboxrule{.6\p@}
\def\theequation{\@arabic\c@equation}
\DeclareOldFontCommand{\rm}{\normalfont\rmfamily}{\mathrm}
\DeclareOldFontCommand{\sf}{\normalfont\sffamily}{\mathsf}
\DeclareOldFontCommand{\tt}{\normalfont\ttfamily}{\mathtt}
\DeclareOldFontCommand{\bf}{\normalfont\bfseries}{\mathbf}
\DeclareOldFontCommand{\it}{\normalfont\itshape}{\mathit}
\DeclareOldFontCommand{\sl}{\normalfont\slshape}{\relax}
\DeclareOldFontCommand{\sc}{\normalfont\scshape}{\relax}
\DeclareRobustCommand*{\cal}{\@fontswitch{\relax}{\mathcal}}
\DeclareRobustCommand*{\mit}{\@fontswitch{\relax}{\mathnormal}}
% end input from slides.cls

% unnumbered list
\def\ul{\bgroup\smallskip
\parindent-8pt
\leftskip=26pt}
\def\endul{\vskip1sp\smallskip\egroup}

\newdimen\footerimagewidth
\footerimagewidth 12.2cm
\newdimen\titleimageheight
\titleimageheight 18mm
\newdimen\footerimageheight
\footerimageheight \titleimageheight

\def\myitem{\,\,\raisebox{1mm}[0pt][0pt]{\includegraphics[height=10pt]{\coldot}\,\,}}

\def\titleslide{\def\@nummi{}\def\@@nummi{}\@@slide<>{}}
\def\slide{\@ifnextchar *{\def\@nummi{}\@slide}%
{\def\@@nummi{\slidenumber}\def\@nummi{\addtocounter{slideno}{1}}\@slide*}}
\def\@slide*{\@ifnextchar <{\@@slide}{\@@slide<>}}


\newif\ifqtmp\qtmptrue
\long\def\@@slide<#1>#2#3{\newif\ifqtmp\qtmptrue\if#1* \iflightbg \qtmpfalse \fi \fi%
\ifqtmp{
\ifbackground{\includegraphics[height=\paperheight,width=\paperwidth]{\@backgroundimage}%
\hspace*{-\paperwidth}\vspace*{-\paperheight}\\}\fi%
\writetitle{#2}%
\begin{minipage}{\slidewidth}%
  \tct#3 %
\end{minipage}\finishslide{\@nummi}{\@@nummi}%
\ifppremarks{\writeppremarks{#1}}\fi%
}\fi}



\newcommand{\writeppremarks}[1]{%
~\vspace*{2.5cm}\\\hspace*{\sleftmargin}%
\renewcommand\baselinestretch{1}\normalsize
\begin{minipage}{\slidewidth}%
\tct\vbox{#1}%
\end{minipage}\newpage}


\newcommand{\finishslide}[2]{{#1}\vfill\ifmkfooter\writefooter\fi\hfill{#2}\newpage}

\newcommand{\writetitle}[1]{%
  \hspace*{\sleftmargin}\ifmkfooter\toptitle\else\vspace*{8mm}\fi\\
  \hspace*{\sleftmargin}%
  \rlap{\includegraphics[height=2cm,
    width=\paperwidth-\sleftmargin]{\@titleimage}}%
  \rlap{\raisebox{5mm}[0mm][0mm]{%
      \hspace*{5mm}\color{\@titlecolor}\LARGE\bfseries{#1}}}%
  \par\hspace*{\sleftmargin}%
}

\newcommand{\writefooter}{%
  \hspace*{\sleftmargin}\rlap{\includegraphics[height=\footerimageheight,
    width=\footerimagewidth]{\@footerimage}}%
  \rlap{\raisebox{6mm}[0mm][0mm]{\hspace*{5mm}\color{\@addcolor}\@footer}}
  \hspace*{\footerimagewidth}\leftfooter%
}

\def\toptitle{\vbox{\includegraphics[height=10pt]{\coldot}\\[-4mm]
\includegraphics[height=10pt]{\coldot}\\[-4mm]
\includegraphics[height=10pt]{\coldot}\\[-8mm]}}

\def\leftfooter{\rlap{\raisebox{.8\footerimageheight}[0mm][0mm]{%
  \hskip03mm\includegraphics[height=10pt]{\coldot}%
  \hskip13mm\includegraphics[height=10pt]{\coldot}%
  \hskip13mm\includegraphics[height=10pt]{\coldot}%
  \hskip13mm\includegraphics[height=10pt]{\coldot}%
  \hskip13mm\includegraphics[height=10pt]{\coldot}%
  \hskip13mm\includegraphics[height=10pt]{\coldot}%
  \hskip13mm\includegraphics[height=10pt]{\coldot}%
  \hskip13mm\includegraphics[height=10pt]{\coldot}%
}}%
}

\def\slidenumber{%
\llap{\raisebox{.3\footerimageheight}[0mm][0mm]{%
\color{\@addcolor}\small\theslideno\hspace*{\srightmargin}}}}

\def\@nummi{}\def\@@nummi{}

\def\footer#1{\def\@footer{#1}}
\def\titleimage#1{\def\@titleimage{\@figuredir#1}}
\def\footerimage#1{\def\@footerimage{\@figuredir#1}}
\def\backgroundimage#1{\def\@backgroundimage{\@figuredir#1}}
\def\titlecolor#1{\def\@titlecolor{#1}}
\def\addcolor#1{\def\@addcolor{#1}}
\def\figuredir#1{\def\@figuredir{#1}}
\def\footeron{\mkfootertrue}
\def\footeroff{\mkfooterfalse}

% standardization of the parameters
\backgroundimage{bgblue.png}
\titleimage{dodgerblue.png}
\footerimage{dodgerblue.png}
\titlecolor{yellow}
\addcolor{gray60}
\footer{}
\figuredir{./p5figures/}

\newcommand{\ppline}{ \rule{\slidewidth}{.2mm}\\}
\newcommand{\pplines}{\ppline\ppline\ppline\ppline\ppline\ppline\ppline\ppline\ppline}


\endinput













